@@ -1,10 +1,10 @@
 #' Change factor levels by hand
 #'
 #' @param .f A factor (or character vector).
-#' @param ... A sequence of named character vectors where the
-#'   name gives the new level, and the value gives the old level.
-#'   Levels not otherwise mentioned will be left as is. Levels can
-#'   be removed by naming them `NULL`. Uses tidy dots.
+#' @param ... <[`dynamic-dots`][rlang::dyn-dots]> A sequence of named character
+#'   vectors where the name gives the new level, and the value gives the old
+#'   level. Levels not otherwise mentioned will be left as is. Levels can
+#'   be removed by naming them `NULL`.
 #' @export
 #' @examples
 #' x <- factor(c("apple", "bear", "banana", "dear"))
@@ -16,6 +16,9 @@
 #' # If you name the level NULL it will be removed
 #' fct_recode(x, NULL = "apple", fruit = "banana")
 #'
+#' # Wrap the left hand side in quotes if it contains special variables
+#' fct_recode(x, "an apple" = "apple", "a bear" = "bear")
+#'
 #' # When passing a named vector to rename levels use !!! to splice
 #' x <- factor(c("apple", "bear", "banana", "dear"))
 #' levels <- c(fruit = "apple", fruit = "banana")
@@ -51,7 +54,7 @@ fct_recode <- function(.f, ...) {
 }
 
 check_recode_levels <- function(...) {
-  levels <- rlang::dots_list(...)
+  levels <- rlang::list2(...)
 
   is_ok <- function(x) is.character(x) && length(x) == 1
   ok <- vapply(levels, is_ok, logical(1))
